@@ -53,7 +53,7 @@
 //! let result = safina_executor::schedule_blocking(|| {
 //!     read_file1()?;
 //!     read_file2()
-//! }).await?;
+//! }).await.unwrap()?;
 //! # Ok(())
 //! # }
 //! # let executor = safina_executor::Executor::default();
@@ -101,7 +101,8 @@
 //!   - Dependencies are full of unsafe
 //!
 //! # Changelog
-//! - V0.2.1 - Update docs.
+//! - v0.3.0 - `schedule_blocking` to return new `safina_sync::Receiver`.
+//! - v0.2.1 - Update docs.
 //! - v0.2.0
 //!   - `Executor::new` and `Executor::with_name` to return `Result`.
 //!   - Upgrade to `safina-threadpool` v0.2.0.
@@ -141,7 +142,7 @@ use core::cell::Cell;
 use core::future::Future;
 use core::pin::Pin;
 use core::task::Poll;
-use safina_sync::Promise;
+use safina_sync::Receiver;
 use safina_threadpool::{NewThreadPoolError, ThreadPool};
 use std::sync::mpsc::SyncSender;
 use std::sync::{Arc, Mutex, Weak};
@@ -248,28 +249,28 @@ impl Executor {
         }))
     }
 
-    /// Schedules `f` to run on any available thread in the blocking thread pool.
+    /// Schedules `func` to run on any available thread in the blocking thread pool.
     ///
     /// Returns immediately.
     ///
-    /// Await the returned promise to get the result of `f`.
-    /// If `f` panics, the promise will never complete.
+    /// Await the returned receiver to get the result of `func`.
+    /// If `func` panics, the receiver returns `TryRecvError::Disconnected`.
     ///
-    /// Puts `f` in a
+    /// Puts `func` in a
     /// [`Box`](https://doc.rust-lang.org/stable/std/boxed/struct.Box.html)
     /// before adding it to the thread pool queue.
-    pub fn schedule_blocking<T: Send + 'static>(
-        self: &Arc<Self>,
-        f: impl (FnOnce() -> T) + Send + 'static,
-    ) -> Promise<T> {
-        let promise = safina_sync::Promise::new();
-        let promise_clone = promise.clone();
+    pub fn schedule_blocking<T, F>(self: &Arc<Self>, func: F) -> Receiver<T>
+    where
+        T: Send + 'static,
+        F: (FnOnce() -> T) + Send + 'static,
+    {
+        let (sender, receiver) = safina_sync::oneshot();
         let weak_self = Arc::downgrade(self);
         self.blocking_pool.schedule(move || {
             let _guard = set_thread_executor(weak_self);
-            promise_clone.set(f());
+            let _result = sender.send(func());
         });
-        promise
+        receiver
     }
 
     /// Adds a task that will execute `fut`.
@@ -382,24 +383,26 @@ impl Default for Executor {
     }
 }
 
-/// Schedules `f` to run on any available thread in the blocking thread pool.
+/// Schedules `func` to run on any available thread in the blocking thread pool.
 ///
 /// Returns immediately.
 ///
-/// Await the returned promise to get the result of `f`.
-/// If `f` panics, the promise will never complete.
+/// Await the returned receiver to get the result of `func`.
+/// If `func` panics, the receiver returns `TryRecvError::Disconnected`.
 ///
-/// Puts `f` in a
+/// Puts `func` in a
 /// [`Box`](https://doc.rust-lang.org/stable/std/boxed/struct.Box.html)
 /// before adding it to the thread pool queue.
 ///
 /// # Panics
 /// Panics if the caller is not running on an [`Executor`](struct.Executor.html).
-pub fn schedule_blocking<T: Send + 'static>(
-    f: impl (FnOnce() -> T) + Send + 'static,
-) -> Promise<T> {
+pub fn schedule_blocking<T, F>(func: F) -> Receiver<T>
+where
+    T: Send + 'static,
+    F: (FnOnce() -> T) + Send + 'static,
+{
     if let Some(executor) = get_thread_executor() {
-        executor.schedule_blocking(f)
+        executor.schedule_blocking(func)
     } else {
         panic!("called from outside a task")
     }
