@@ -78,6 +78,7 @@ async fn measure_blocking_concurrency(executor: &Arc<Executor>, num_jobs: usize)
     for promise in promises {
         safina_timer::with_deadline(promise, deadline)
             .await
+            .unwrap()
             .unwrap();
     }
     let elapsed = before.elapsed();
@@ -121,6 +122,7 @@ async fn get_blocking_thread_name(executor: &Arc<Executor>) -> String {
     executor
         .schedule_blocking(|| std::thread::current().name().unwrap().to_string())
         .await
+        .unwrap()
 }
 
 #[test]
@@ -352,9 +354,18 @@ fn test_executor_schedule_blocking() {
     let executor = safina_executor::Executor::new(2, 2).unwrap();
     let executor_clone = executor.clone();
     executor.block_on(async move {
-        assert_eq!(3_u8, executor_clone.schedule_blocking(|| 3_u8).await);
+        assert_eq!(
+            3_u8,
+            executor_clone.schedule_blocking(|| 3_u8).await.unwrap()
+        );
         let value = 5_u8;
-        assert_eq!(5_u8, executor_clone.schedule_blocking(move || value).await);
+        assert_eq!(
+            5_u8,
+            executor_clone
+                .schedule_blocking(move || value)
+                .await
+                .unwrap()
+        );
         let before = Instant::now();
         assert_eq!(
             7_u8,
@@ -364,30 +375,29 @@ fn test_executor_schedule_blocking() {
                     7_u8
                 })
                 .await
+                .unwrap()
         );
         expect_elapsed(
             before,
             Duration::from_millis(100)..Duration::from_millis(200),
         );
-        safina_timer::with_timeout(
-            executor_clone.schedule_blocking(|| {
+        executor_clone
+            .schedule_blocking(|| {
                 #[allow(clippy::manual_assert)]
                 if true {
                     panic!("ignore this panic");
                 }
                 1_u8
-            }),
-            Duration::from_millis(500),
-        )
-        .await
-        .unwrap_err();
+            })
+            .await
+            .unwrap_err();
 
         let before = Instant::now();
         let (sender, receiver) = std::sync::mpsc::channel();
         let promise = executor_clone.schedule_blocking(move || receiver.recv().unwrap());
         safina_timer::sleep_for(Duration::from_millis(100)).await;
         sender.send(9_u8).unwrap();
-        assert_eq!(9_u8, promise.await);
+        assert_eq!(9_u8, promise.await.unwrap());
         expect_elapsed(
             before,
             Duration::from_millis(100)..Duration::from_millis(200),
@@ -400,11 +410,16 @@ fn test_schedule_blocking() {
     safina_timer::start_timer_thread();
     let executor = safina_executor::Executor::new(1, 1).unwrap();
     executor.block_on(async {
-        assert_eq!(3_u8, safina_executor::schedule_blocking(|| 3_u8).await);
+        assert_eq!(
+            3_u8,
+            safina_executor::schedule_blocking(|| 3_u8).await.unwrap()
+        );
         let value = 5_u8;
         assert_eq!(
             5_u8,
-            safina_executor::schedule_blocking(move || value).await
+            safina_executor::schedule_blocking(move || value)
+                .await
+                .unwrap()
         );
         let before = Instant::now();
         assert_eq!(
@@ -414,21 +429,19 @@ fn test_schedule_blocking() {
                 7_u8
             })
             .await
+            .unwrap()
         );
         expect_elapsed(
             before,
             Duration::from_millis(100)..Duration::from_millis(200),
         );
-        safina_timer::with_timeout(
-            safina_executor::schedule_blocking(|| {
-                #[allow(clippy::manual_assert)]
-                if true {
-                    panic!("ignore this panic");
-                }
-                1_u8
-            }),
-            Duration::from_millis(500),
-        )
+        safina_executor::schedule_blocking(|| {
+            #[allow(clippy::manual_assert)]
+            if true {
+                panic!("ignore this panic");
+            }
+            1_u8
+        })
         .await
         .unwrap_err();
 
@@ -437,7 +450,7 @@ fn test_schedule_blocking() {
         let promise = safina_executor::schedule_blocking(move || receiver.recv().unwrap());
         safina_timer::sleep_for(Duration::from_millis(100)).await;
         sender.send(9_u8).unwrap();
-        assert_eq!(9_u8, promise.await);
+        assert_eq!(9_u8, promise.await.unwrap());
         expect_elapsed(
             before,
             Duration::from_millis(100)..Duration::from_millis(200),
